mypo is a Python module for making strategy your portfolio and is distributed under the MIT license.

Installation
============

You can install the latest this module with the command:


    pip install mypo

Quick start
============

You can start quickly  by using docker image with the command.


    git clone https://github.com/sonesuke/mypo.git
    docker-compose up

After starting Jupyter server, you can login it with the token. The default of token is '1111'.


Important links
===============

- Documentation: https://sonesuke.github.io/mypo
- Official source code repo: https://github.com/sonesuke/mypo
- Download releases: https://pypi.org/project/mypo/
- Issue tracker: https://github.com/sonesuke/mypo/issues

Citation
========
If you use mypo in a publication, we would appreciate citations: https://sonesuke.github.io/mypo/